==> feathercoin_0.18.1.orig.tar.gz: feathercoin-0.18.1/src/qt/locale/bitcoin_ml.ts <==
<TS language="ml" version="2.1">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Right-click to edit address or label</source>
        <translation>വിലാസം അല്ലെങ്കിൽ ലേബൽ എഡിറ്റുചെയ്യാൻ വലത് ക്ലിക്കുചെയ്യുക</translation>
    </message>
    <message>
        <source>Create a new address</source>
        <translation>ഒരു പുതിയ വിലാസം സൃഷ്ടിക്കുക</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;പുതിയത്</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>നിലവിൽ തിരഞ്ഞെടുത്ത വിലാസം സിസ്റ്റം ക്ലിപ്പ്ബോർഡിലേക്ക് പകർത്തുക</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp; പകർത്തുക
</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation>അ&amp;ടയ്ക്കുക</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>പട്ടികയിൽ നിന്ന് നിലവിൽ തിരഞ്ഞെടുത്ത വിലാസം ഇല്ലാതാക്കുക</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>നിലവിലെ ടാബിൽ ഒരു ഫയലിൽ ഡാറ്റ എക്സ്പോർട്ട് ചെയ്യുക</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation>&amp; കയറ്റുമതി ചെയ്യുക</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;ഇല്ലാതാക്കുക</translation>
    </message>
    <message>
        <source>Choose the address to send coins to</source>
        <translation>നാണയങ്ങൾ അയയ്ക്കാനുള്ള വിലാസം തിരഞ്ഞെടുക്കുക</translation>
    </message>
    <message>
        <source>Choose the address to receive coins with</source>
        <translation>നാണയങ്ങൾ സ്വീകരിക്കാൻ വിലാസം തിരഞ്ഞെടുക്കുക</translation>
    </message>
    <message>
        <source>C&amp;hoose</source>
        <translation>തി&amp;രഞ്ഞെടുക്കുക</translation>
    </message>
    <message>
        <source>Sending addresses</source>
        <translation>വിലാസങ്ങൾ അയയ്ക്കുന്നു</translation>
    </message>
    <message>
        <source>Receiving addresses</source>
        <translation>സ്വീകരിക്കുന്ന വിലാസങ്ങൾ</translation>
    </message>
    <message>
        <source>These are your Feathercoin addresses for sending payments. Always check the amount and the receiving address before sending coins.</source>
        <translation>പേയ്മെന്റുകൾ അയയ്ക്കുന്നതിനുള്ള നിങ്ങളുടെ ബിറ്റ്കോയിൻ വിലാസങ്ങളാണ് ഇവ. നാണയങ്ങൾ അയയ്ക്കുന്നതിനുമുമ്പ് എല്ലായ്പ്പോഴും തുകയും സ്വീകരിക്കുന്ന വിലാസവും പരിശോധിക്കുക.</translation>
    </message>
    <message>
        <source>These are your Feathercoin addresses for receiving payments. It is recommended to use a new receiving address for each transaction.</source>
        <translation>പേയ്മെന്റ് സ്വീകരിക്കുന്നതിന് നിങ്ങളുടെ ബിറ്റ്കോയിൻ വിലാസങ്ങളാണ് ഇവ. ഓരോ ഇടപാടിനും പുതിയ സ്വീകരിക്കുന്ന വിലാസം ഉപയോഗിക്കുന്നതാണ് ഉചിതം.</translation>
    </message>
    <message>
        <source>&amp;Copy Address</source>
        <translation>&amp;വിലാസം പകർത്തുക</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation>പകർത്തുക &amp;ലേബൽ</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;ചിട്ടപ്പെടുത്തുക</translation>
    </message>
    <message>
        <source>Export Address List</source>
        <translation>കയറ്റുമതി വിലാസ ലിസ്റ്റ്</translation>
    </message>
    <message>
        <source>Comma separated file (*.csv)</source>
        <translation>കോമയാൽ വേർതിരിച്ച ഫയൽ (* .csv)</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation>കയറ്റുമതി പരാജയപ്പെട്ടു</translation>
    </message>
    </context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation>ലേബൽ</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>വിലാസം</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(ലേബൽ ഇല്ല)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation>രഹസ്യപദപ്രയോഗ സംഭാഷണം</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation>രഹസ്യപദപ്രയോഗം നൽകുക</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>പുതിയ രഹസ്യപദപ്രയോഗം</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>പുതിയ രഹസ്യപദപ്രയോഗം ആവർത്തിക്കുക</translation>
    </message>
    <message>
        <source>Enter the new passphrase to the wallet.&lt;br/&gt;Please use a passphrase of &lt;b&gt;ten or more random characters&lt;/b&gt;, or &lt;b&gt;eight or more words&lt;/b&gt;.</source>
        <translation>വാലറ്റിൽ പുതിയ രഹസ്യപദപ്രയോഗം നൽകുക. &lt;br/&gt; &lt;b&gt; പത്തോ അതിലധികമോ റാൻഡം പ്രതീകങ്ങൾ &lt;/ b&gt; അല്ലെങ്കിൽ &lt;b&gt; എട്ട് അല്ലെങ്കിൽ അതിൽ കൂടുതൽ വാക്കുകൾ &lt;/ b&gt; ഒരു രഹസ്യപദപ്രയോഗം ഉപയോഗിക്കുക.</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation>വാലറ്റ് എൻക്രിപ്റ്റ് ചെയ്യുക</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation>നിങ്ങളുടെ വാലറ്റ് അൺലോക്കുചെയ്യാൻ ഈ പ്രവർത്തനത്തിന് നിങ്ങളുടെ വാലറ്റ് രഹസ്യപദപ്രയോഗം ആവശ്യമാണ്.</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation>വാലറ്റ് അൺലോക്ക് ചെയ്യുക</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to decrypt the wallet.</source>
        <translation>ഈ പ്രവർത്തനത്തിന് വാലറ്റ് ഡീക്രിപ്റ്റ് ചെയ്യുന്നതിന് നിങ്ങളുടെ വാലറ്റ് പാസ്ഫ്രെയ്സ് ആവശ്യമാണ്.</translation>
    </message>
    <message>
        <source>Decrypt wallet</source>
        <translation>വാലറ്റ് ഡീക്രിപ്റ്റ് ചെയ്യുക</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation>പാസ്ഫ്രെയ്സ് മാറ്റുക</translation>
    </message>
    <message>
        <source>Enter the old passphrase and new passphrase to the wallet.</source>
        <translation>പഴയ രഹസ്യപദപ്രയോഗം പുതിയ രഹസ്യപദപ്രയോഗം വാലറ്റിൽ നൽകുക.</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation>വാലറ്റ് എൻക്രിപ്ഷൻ സ്ഥിരീകരിക്കുക</translation>
    </message>
    <message>
        <source>Warning: If you encrypt your wallet and lose your passphrase, you will &lt;b&gt;LOSE ALL OF YOUR FEATHERCOINS&lt;/b&gt;!</source>
        <translation>മുന്നറിയിപ്പ്: നിങ്ങളുടെ വാലറ്റ് എൻക്രിപ്റ്റ് ചെയ്ത് പാസ്ഫ്രെയ്സ് നഷ്ടപ്പെടുകയാണെങ്കിൽ, നിങ്ങളുടെ എല്ലാ ബിറ്റ്കൊയിനുകളും നഷ്ടപ്പെടും!</translation>
    </message>
    </context>
<context>
    <name>BanTableModel</name>
    </context>
<context>
    <name>BitcoinGUI</name>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>(no label)</source>
        <translation>(ലേബൽ ഇല്ല)</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    </context>
<context>
    <name>FreespaceChecker</name>
    </context>
<context>
    <name>HelpMessageDialog</name>
    </context>
<context>
    <name>Intro</name>
    </context>
<context>
    <name>ModalOverlay</name>
    </context>
<context>
    <name>OpenURIDialog</name>
    </context>
<context>
    <name>OptionsDialog</name>
    </context>
<context>
    <name>OverviewPage</name>
    </context>
<context>
    <name>PaymentServer</name>
    </context>
<context>
    <name>PeerTableModel</name>
    </context>
<context>
    <name>QObject</name>
    </context>
<context>
    <name>QObject::QObject</name>
    </context>
<context>
    <name>QRImageWidget</name>
    </context>
<context>
    <name>RPCConsole</name>
    </context>
<context>
    <name>ReceiveCoinsDialog</name>
    </context>
<context>
    <name>ReceiveRequestDialog</name>
    <message>
        <source>Address</source>
        <translation>വിലാസം</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>ലേബൽ</translation>
    </message>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    <message>
        <source>Label</source>
        <translation>ലേബൽ</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(ലേബൽ ഇല്ല)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>(no label)</source>
        <translation>(ലേബൽ ഇല്ല)</translation>
    </message>
</context>
<context>
    <name>SendCoinsEntry</name>
    </context>
<context>
    <name>SendConfirmationDialog</name>
    </context>
<context>
    <name>ShutdownWindow</name>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    </context>
<context>
    <name>SplashScreen</name>
    </context>
<context>
    <name>TrafficGraphWidget</name>
    </context>
<context>
    <name>TransactionDesc</name>
    </context>
<context>
    <name>TransactionDescDialog</name>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Label</source>
        <translation>ലേബൽ</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(ലേബൽ ഇല്ല)</translation>
    </message>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Comma separated file (*.csv)</source>
        <translation>കോമയാൽ വേർതിരിച്ച ഫയൽ (* .csv)</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>ലേബൽ</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>വിലാസം</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation>കയറ്റുമതി പരാജയപ്പെട്ടു</translation>
    </message>
    </context>
<context>
    <name>UnitDisplayStatusBarControl</name>
    </context>
<context>
    <name>WalletController</name>
    </context>
<context>
    <name>WalletFrame</name>
    </context>
<context>
    <name>WalletModel</name>
    </context>
<context>
    <name>WalletView</name>
    <message>
        <source>&amp;Export</source>
        <translation>&amp; കയറ്റുമതി ചെയ്യുക</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>നിലവിലെ ടാബിൽ ഒരു ഫയലിൽ ഡാറ്റ എക്സ്പോർട്ട് ചെയ്യുക</translation>
    </message>
    </context>
<context>
    <name>bitcoin-core</name>
    </context>
</TS>

==> feathercoin_0.19.1.orig.tar.gz: feathercoin-v0.19.1/src/qt/locale/bitcoin_ml.ts <==
<TS language="ml" version="2.1">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Right-click to edit address or label</source>
        <translation>വിലാസം അല്ലെങ്കിൽ ലേബൽ എഡിറ്റുചെയ്യാൻ വലത് ക്ലിക്കുചെയ്യുക</translation>
    </message>
    <message>
        <source>Create a new address</source>
        <translation>ഒരു പുതിയ വിലാസം സൃഷ്ടിക്കുക</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;പുതിയത്</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>നിലവിൽ തിരഞ്ഞെടുത്ത വിലാസം സിസ്റ്റം ക്ലിപ്പ്ബോർഡിലേക്ക് പകർത്തുക</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp; പകർത്തുക
</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation>അ&amp;ടയ്ക്കുക</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>പട്ടികയിൽ നിന്ന് നിലവിൽ തിരഞ്ഞെടുത്ത വിലാസം ഇല്ലാതാക്കുക</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>നിലവിലെ ടാബിൽ ഒരു ഫയലിൽ ഡാറ്റ എക്സ്പോർട്ട് ചെയ്യുക</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation>&amp; കയറ്റുമതി ചെയ്യുക</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;ഇല്ലാതാക്കുക</translation>
    </message>
    <message>
        <source>Choose the address to send coins to</source>
        <translation>നാണയങ്ങൾ അയയ്ക്കാനുള്ള വിലാസം തിരഞ്ഞെടുക്കുക</translation>
    </message>
    <message>
        <source>Choose the address to receive coins with</source>
        <translation>നാണയങ്ങൾ സ്വീകരിക്കാൻ വിലാസം തിരഞ്ഞെടുക്കുക</translation>
    </message>
    <message>
        <source>C&amp;hoose</source>
        <translation>തി&amp;രഞ്ഞെടുക്കുക</translation>
    </message>
    <message>
        <source>Sending addresses</source>
        <translation>വിലാസങ്ങൾ അയയ്ക്കുന്നു</translation>
    </message>
    <message>
        <source>Receiving addresses</source>
        <translation>സ്വീകരിക്കുന്ന വിലാസങ്ങൾ</translation>
    </message>
    <message>
        <source>These are your Feathercoin addresses for sending payments. Always check the amount and the receiving address before sending coins.</source>
        <translation>പേയ്മെന്റുകൾ അയയ്ക്കുന്നതിനുള്ള നിങ്ങളുടെ ബിറ്റ്കോയിൻ വിലാസങ്ങളാണ് ഇവ. നാണയങ്ങൾ അയയ്ക്കുന്നതിനുമുമ്പ് എല്ലായ്പ്പോഴും തുകയും സ്വീകരിക്കുന്ന വിലാസവും പരിശോധിക്കുക.</translation>
    </message>
    <message>
        <source>&amp;Copy Address</source>
        <translation>&amp;വിലാസം പകർത്തുക</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation>പകർത്തുക &amp;ലേബൽ</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;ചിട്ടപ്പെടുത്തുക</translation>
    </message>
    <message>
        <source>Export Address List</source>
        <translation>കയറ്റുമതി വിലാസ ലിസ്റ്റ്</translation>
    </message>
    <message>
        <source>Comma separated file (*.csv)</source>
        <translation>കോമയാൽ വേർതിരിച്ച ഫയൽ (* .csv)</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation>കയറ്റുമതി പരാജയപ്പെട്ടു</translation>
    </message>
    <message>
        <source>There was an error trying to save the address list to %1. Please try again.</source>
        <translation>%1 ലേക്ക് വിലാസ ലിസ്റ്റ് സംരക്ഷിക്കാൻ ശ്രമിക്കുന്നതിൽ ഒരു പിശകുണ്ടായിരുന്നു. വീണ്ടും ശ്രമിക്കുക.</translation>
    </message>
</context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation>ലേബൽ</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>വിലാസം</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(ലേബൽ ഇല്ല)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation>രഹസ്യപദപ്രയോഗ സംഭാഷണം</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation>രഹസ്യപദപ്രയോഗം നൽകുക</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>പുതിയ രഹസ്യപദപ്രയോഗം</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>പുതിയ രഹസ്യപദപ്രയോഗം ആവർത്തിക്കുക</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation>വാലറ്റ് എൻക്രിപ്റ്റ് ചെയ്യുക</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation>നിങ്ങളുടെ വാലറ്റ് അൺലോക്കുചെയ്യാൻ ഈ പ്രവർത്തനത്തിന് നിങ്ങളുടെ വാലറ്റ് രഹസ്യപദപ്രയോഗം ആവശ്യമാണ്.</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation>വാലറ്റ് അൺലോക്ക് ചെയ്യുക</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to decrypt the wallet.</source>
        <translation>ഈ പ്രവർത്തനത്തിന് വാലറ്റ് ഡീക്രിപ്റ്റ് ചെയ്യുന്നതിന് നിങ്ങളുടെ വാലറ്റ് പാസ്ഫ്രെയ്സ് ആവശ്യമാണ്.</translation>
    </message>
    <message>
        <source>Decrypt wallet</source>
        <translation>വാലറ്റ് ഡീക്രിപ്റ്റ് ചെയ്യുക</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation>പാസ്ഫ്രെയ്സ് മാറ്റുക</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation>വാലറ്റ് എൻക്രിപ്ഷൻ സ്ഥിരീകരിക്കുക</translation>
    </message>
    <message>
        <source>Warning: If you encrypt your wallet and lose your passphrase, you will &lt;b&gt;LOSE ALL OF YOUR BITCOINS&lt;/b&gt;!</source>
        <translation>മുന്നറിയിപ്പ്: നിങ്ങളുടെ വാലറ്റ് എൻക്രിപ്റ്റ് ചെയ്ത് പാസ്ഫ്രെയ്സ് നഷ്ടപ്പെടുകയാണെങ്കിൽ, നിങ്ങളുടെ എല്ലാ ബിറ്റ്കൊയിനുകളും നഷ്ടപ്പെടും!</translation>
    </message>
    </context>
<context>
    <name>BanTableModel</name>
    </context>
<context>
    <name>BitcoinGUI</name>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>(no label)</source>
        <translation>(ലേബൽ ഇല്ല)</translation>
    </message>
    </context>
<context>
    <name>CreateWalletActivity</name>
    </context>
<context>
    <name>CreateWalletDialog</name>
    </context>
<context>
    <name>EditAddressDialog</name>
    </context>
<context>
    <name>FreespaceChecker</name>
    </context>
<context>
    <name>HelpMessageDialog</name>
    </context>
<context>
    <name>Intro</name>
    </context>
<context>
    <name>ModalOverlay</name>
    </context>
<context>
    <name>OpenURIDialog</name>
    </context>
<context>
    <name>OpenWalletActivity</name>
    </context>
<context>
    <name>OptionsDialog</name>
    </context>
<context>
    <name>OverviewPage</name>
    </context>
<context>
    <name>PaymentServer</name>
    </context>
<context>
    <name>PeerTableModel</name>
    </context>
<context>
    <name>QObject</name>
    </context>
<context>
    <name>QRImageWidget</name>
    </context>
<context>
    <name>RPCConsole</name>
    </context>
<context>
    <name>ReceiveCoinsDialog</name>
    </context>
<context>
    <name>ReceiveRequestDialog</name>
    <message>
        <source>Address</source>
        <translation>വിലാസം</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>ലേബൽ</translation>
    </message>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    <message>
        <source>Label</source>
        <translation>ലേബൽ</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(ലേബൽ ഇല്ല)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>(no label)</source>
        <translation>(ലേബൽ ഇല്ല)</translation>
    </message>
</context>
<context>
    <name>SendCoinsEntry</name>
    </context>
<context>
    <name>SendConfirmationDialog</name>
    </context>
<context>
    <name>ShutdownWindow</name>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    </context>
<context>
    <name>TrafficGraphWidget</name>
    </context>
<context>
    <name>TransactionDesc</name>
    </context>
<context>
    <name>TransactionDescDialog</name>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Label</source>
        <translation>ലേബൽ</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(ലേബൽ ഇല്ല)</translation>
    </message>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Comma separated file (*.csv)</source>
        <translation>കോമയാൽ വേർതിരിച്ച ഫയൽ (* .csv)</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>ലേബൽ</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>വിലാസം</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation>കയറ്റുമതി പരാജയപ്പെട്ടു</translation>
    </message>
    </context>
<context>
    <name>UnitDisplayStatusBarControl</name>
    </context>
<context>
    <name>WalletController</name>
    </context>
<context>
    <name>WalletFrame</name>
    </context>
<context>
    <name>WalletModel</name>
    </context>
<context>
    <name>WalletView</name>
    <message>
        <source>&amp;Export</source>
        <translation>&amp; കയറ്റുമതി ചെയ്യുക</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>നിലവിലെ ടാബിൽ ഒരു ഫയലിൽ ഡാറ്റ എക്സ്പോർട്ട് ചെയ്യുക</translation>
    </message>
    </context>
<context>
    <name>bitcoin-core</name>
    </context>
</TS>
